@@ -2,6 +2,6 @@ import importlib.metadata
 
 __version__ = importlib.metadata.version("strangeworks-annealing")
 
-from .problem import qubo_energy, upload_problem
+from .problem import qubo_energy, load_problem
 from .solver import get_solvers, select_solver
 from .sampler import SWDWaveSampler
